# Common problems

- Problems may occur due to incompatible [detect_product_long] / [bd_product_long] versions. Consult the [Compatibility Matrix](https://documentation.blackduck.com/bundle/blackduck-compatibility/page/topics/Black-Duck-Release-Compatibility.html) to verify your combination. Attempting to reproduce the problem using the latest version of [bd_product_short] with the latest version of [bd_product_short] might also assist in determining if the issue has been resolved.
- Remember to consider the possibility that the [bd_product_short] user lacks the necessary permissions (to create the project, update the BOM, receive notifications, etc.) in [bd_product_short]. For more information, see [Black Duck user role requirements](../gettingstarted/usersandroles.md).
- Confirm that the [bd_product_short] server (registration key) has the required capabilities enabled (binary upload, snippet scanning, etc.).

## Incorrect or missing components

- For issues related to tools invoked by [detect_product_short] ([blackduck_signature_scanner_name], Docker Inspector, etc.), please check that tool's documentation.
- Issues related to incorrect components in the [bd_product_short] BOM.    
	- [detect_product_short] configuration has control over matches produced by detectors (that are written to BDIO files), but no control over matches produced by the [blackduck_signature_scanner_name] / [bd_product_short]. When investigating an incorrect component in a [bd_product_short] BOM, you need to determine whether the component was contributed by a detector, or by the [blackduck_signature_scanner_name]: On the [blackduck_product_name] Components tab for the project/version: Click on the *N Matches* link next to the component. The next screen lists the matches on the right-hand side. Matches from the [blackduck_signature_scanner_name] have a filename in the *Name* column. Matches from detectors have an external ID (such as "org.hamcrest:hamcrest-core:1.3") in the *Name* column.
- For issues related to components missing from, or incorrectly categorized, in the [bd_product_short] BOM.    
	- [detect_product_short] configuration has control over the production of BDIO files (use [--detect.diagnostic](../properties/configuration/debug.md#diagnostic-mode) to save these), but no control over how they are converted into a BOM by [bd_product_short]. A good first step is to determine whether the BDIO files produced are correct. If they are incorrect, the problem is related to what [detect_product_short] is doing. If they are correct, but the BOM is incorrect, the problem is related to what [bd_product_short] is doing. Similarly, [detect_product_short] is responsible for passing the correct arguments to the [blackduck_signature_scanner_name], but beyond that has no control over the results it produces.

## Spring Boot related issues

- [detect_product_short] is a Spring Boot application, and leverages Spring Boot to provide various mechanisms to configure it through [property settings](https://docs.spring.io/spring-boot/docs/current/reference/html/boot-features-external-config.html). Spring Boot flexibility makes it's possible for [detect_product_short] to be influenced by files (application.properties, application.xml, etc.) that might exist in the directory from which [detect_product_short] is run that are intended for some other application and produce unexpected results. If properties have unexpected values (see the [detect_product_short] log), this should be reviewed. The best solution may be to run [detect_product_short] from a different empty directory using the `--detect.source.path argument` parameter.
- Similarly, [detect_product_short] might be influenced by environment variables via the same Spring Boot mechanism, so check the environment for variables that correspond to [detect_product_short] property names.

